<?php

namespace App\Http\Controllers;

use Illuminate\Http\JsonResponse;
use App\Http\Requests\MetricCalculatorRequest;
use App\Models\MetricCalculation;

class MetricCalculatorController extends Controller
{
    public function calculate(MetricCalculatorRequest $request): JsonResponse
    {
        $data = $request->validated();

        // Cálculo das métricas
        $vendas_necessarias = $data['meta_faturamento'] / $data['ticket_medio'];
        $reunioes_necessarias = $vendas_necessarias / $data['taxa_conversao'];
        $reunioes_agendadas = $reunioes_necessarias / (1 - $data['taxa_nao_comparecimento']);
        $closers_necessarios = max(1, ceil($reunioes_agendadas / 100));
        $sdrs_necessarios = max(1, ceil(($reunioes_agendadas * $data['leads_por_agendamento']) / 500));

        // Cálculo dos gerentes
        $total_colaboradores = $closers_necessarios + $sdrs_necessarios;
        $gerentes_necessarios = 0;
        $coordenadores_necessarios = 0;
        $diretores_necessarios = 0;
        $head_de_vendas = 0;

        if ($total_colaboradores >= 4 && $total_colaboradores <= 8) {
            $gerentes_necessarios = 1;
        } elseif ($total_colaboradores > 8) {
            $gerentes_necessarios = ceil($total_colaboradores / 8);
        }

        if ($gerentes_necessarios > 3) {
            $head_de_vendas = 1;
        }

        if ($total_colaboradores > 25) {
            $coordenadores_necessarios = ceil($gerentes_necessarios / 3);
        }

        if ($coordenadores_necessarios >= 2) {
            $diretores_necessarios = 1;
        }

        // Salvar no banco de dados
        $metric = MetricCalculation::create([
            'meta_faturamento' => $data['meta_faturamento'],
            'ticket_medio' => $data['ticket_medio'],
            'taxa_conversao' => $data['taxa_conversao'],
            'taxa_nao_comparecimento' => $data['taxa_nao_comparecimento'],
            'leads_por_agendamento' => $data['leads_por_agendamento'],
            'equipe_sdr' => $data['equipe_sdr'],
            'equipe_closer' => $data['equipe_closer'],
            'vendas_necessarias' => $vendas_necessarias,
            'reunioes_necessarias' => $reunioes_necessarias,
            'reunioes_agendadas' => $reunioes_agendadas,
            'closers_necessarios' => $closers_necessarios,
            'sdrs_necessarios' => $sdrs_necessarios,
            'gerentes_necessarios' => $gerentes_necessarios,
            'head_de_vendas' => $head_de_vendas,
            'coordenadores_necessarios' => $coordenadores_necessarios,
            'diretores_necessarios' => $diretores_necessarios,
        ]);

        return response()->json([
            'vendas_necessarias' => number_format($vendas_necessarias, 0),
            'reunioes_necessarias' => number_format($reunioes_necessarias, 0),
            'reunioes_agendadas' => number_format($reunioes_agendadas, 0),
            'closers_necessarios' => number_format($closers_necessarios, 0),
            'sdrs_necessarios' => number_format($sdrs_necessarios, 0),
            'gerentes_necessarios' => number_format($gerentes_necessarios, 0),
            'head_de_vendas' => number_format($head_de_vendas, 0),
            'coordenadores_necessarios' => number_format($coordenadores_necessarios, 0),
            'diretores_necessarios' => number_format($diretores_necessarios, 0),
        ]);

    }
}
